@@ -14,7 +14,7 @@
 
 from __future__ import annotations
 
-from typing import Optional, Callable
+from typing import Callable, Optional, Union
 
 from supertokens_python import AppInfo, RecipeModule
 from supertokens_python.recipe.dashboard.utils import InputOverrideConfig
@@ -23,7 +23,7 @@ from .recipe import DashboardRecipe
 
 
 def init(
-    api_key: str,
+    api_key: Union[str, None] = None,
     override: Optional[InputOverrideConfig] = None,
 ) -> Callable[[AppInfo], RecipeModule]:
     return DashboardRecipe.init(
