@@ -8,3 +8,5 @@ USER_METADATA_API = "/api/user/metadata"
 USER_SESSION_API = "/api/user/sessions"
 USER_PASSWORD_API = "/api/user/password"
 USER_EMAIL_VERIFY_TOKEN_API = "/api/user/email/verify/token"
+EMAIL_PASSWORD_SIGN_IN = "/api/signin"
+EMAIL_PASSSWORD_SIGNOUT = "/api/signout"
