@@ -23,6 +23,8 @@ from .api import (
     api_key_protector,
     handle_dashboard_api,
     handle_email_verify_token_post,
+    handle_emailpassword_signin_api,
+    handle_emailpassword_signout_api,
     handle_metadata_get,
     handle_metadata_put,
     handle_sessions_get,
@@ -52,6 +54,8 @@ from supertokens_python.exceptions import SuperTokensError, raise_general_except
 
 from .constants import (
     DASHBOARD_API,
+    EMAIL_PASSSWORD_SIGNOUT,
+    EMAIL_PASSWORD_SIGN_IN,
     USER_API,
     USER_EMAIL_VERIFY_API,
     USER_EMAIL_VERIFY_TOKEN_API,
@@ -78,7 +82,7 @@ class DashboardRecipe(RecipeModule):
         self,
         recipe_id: str,
         app_info: AppInfo,
-        api_key: str,
+        api_key: Union[str, None],
         override: Union[InputOverrideConfig, None] = None,
     ):
         super().__init__(recipe_id, app_info)
@@ -136,6 +140,10 @@ class DashboardRecipe(RecipeModule):
             return await handle_dashboard_api(self.api_implementation, api_options)
         if request_id == VALIDATE_KEY_API:
             return await handle_validate_key_api(self.api_implementation, api_options)
+        if request_id == EMAIL_PASSWORD_SIGN_IN:
+            return await handle_emailpassword_signin_api(
+                self.api_implementation, api_options
+            )
 
         # Do API key validation for the remaining APIs
         api_function: Optional[
@@ -171,6 +179,8 @@ class DashboardRecipe(RecipeModule):
             api_function = handle_user_password_put
         elif request_id == USER_EMAIL_VERIFY_TOKEN_API:
             api_function = handle_email_verify_token_post
+        elif request_id == EMAIL_PASSSWORD_SIGNOUT:
+            api_function = handle_emailpassword_signout_api
 
         if api_function is not None:
             return await api_key_protector(
@@ -189,7 +199,7 @@ class DashboardRecipe(RecipeModule):
 
     @staticmethod
     def init(
-        api_key: str,
+        api_key: Union[str, None],
         override: Union[InputOverrideConfig, None] = None,
     ):
         def func(app_info: AppInfo):
