@@ -483,13 +483,6 @@ html_template = """
 			text-decoration: underline;
 		}
 
-		@media only screen and (min-width:768px) {
-			.templateContainer {
-				width: 600px !important;
-			}
-
-		}
-
 		@media only screen and (max-width: 480px) {
 
 			body,
