@@ -14,5 +14,4 @@
 
 from __future__ import annotations
 
-from .recipe_implementation import \
-    get_recipe_implementation_with_jwt  # type: ignore
+from .recipe_implementation import get_recipe_implementation_with_jwt  # type: ignore
