@@ -140,7 +140,7 @@ async def test_email_verify_default_backward_compatibility(
                     Github(client_id="", client_secret="")
                 ],  # Note: providers must be set to init tp recipe
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -154,7 +154,7 @@ async def test_email_verify_default_backward_compatibility(
         raise Exception("Should never come here")
     assert isinstance(resp, ThirdPartySignInUpOkResult)
     user_id = resp.user.user_id
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -174,7 +174,6 @@ async def test_email_verify_default_backward_compatibility(
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -222,7 +221,7 @@ async def test_email_verify_backward_compatibility(driver_config_client: TestCli
                     Github(client_id="", client_secret="")
                 ],  # Note: providers must be set to init tp recipe
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -236,12 +235,11 @@ async def test_email_verify_backward_compatibility(driver_config_client: TestCli
         raise Exception("Should never come here")
     assert isinstance(resp, ThirdPartySignInUpOkResult)
     user_id = resp.user.user_id
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     resp = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
@@ -301,7 +299,7 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
                     Github(client_id="", client_secret="")
                 ],  # Note: providers must be set to init tp recipe
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -316,7 +314,7 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
     assert isinstance(resp, ThirdPartySignInUpOkResult)
     user_id = resp.user.user_id
     assert isinstance(user_id, str)
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     def api_side_effect(request: httpx.Request):
         nonlocal app_name, email, email_verify_url
@@ -333,7 +331,6 @@ async def test_email_verify_custom_override(driver_config_client: TestClient):
         resp = email_verify_token_request(
             driver_config_client,
             response["accessToken"]["token"],
-            response["idRefreshToken"]["token"],
             response.get("antiCsrf", ""),
             user_id,
             True,
@@ -442,7 +439,7 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
                     Github(client_id="", client_secret="")
                 ],  # Note: providers must be set to init tp recipe
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -457,12 +454,11 @@ async def test_email_verify_smtp_service(driver_config_client: TestClient):
     assert isinstance(resp, ThirdPartySignInUpOkResult)
     user_id = resp.user.user_id
     assert isinstance(user_id, str)
-    response = await create_new_session(s.recipe_implementation, user_id, {}, {})
+    response = await create_new_session(s.recipe_implementation, user_id, True, {}, {})
 
     resp = email_verify_token_request(
         driver_config_client,
         response["accessToken"]["token"],
-        response["idRefreshToken"]["token"],
         response.get("antiCsrf", ""),
         user_id,
         True,
@@ -557,7 +553,7 @@ async def test_email_verify_for_pless_user_no_callback():
                     override=email_delivery_override,
                 ),
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -603,7 +599,7 @@ async def test_pless_login_default_backward_compatibility(
                 contact_config=passwordless.ContactEmailOnlyConfig(),
                 flow_type="USER_INPUT_CODE_AND_MAGIC_LINK",
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -693,7 +689,7 @@ async def test_pless_login_default_backward_compatibility_no_suppress_error(
                 contact_config=passwordless.ContactEmailOnlyConfig(),
                 flow_type="USER_INPUT_CODE_AND_MAGIC_LINK",
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -765,7 +761,7 @@ async def test_pless_login_backward_compatibility(driver_config_client: TestClie
                 ),
                 flow_type="USER_INPUT_CODE_AND_MAGIC_LINK",
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -847,7 +843,7 @@ async def test_pless_login_custom_override(driver_config_client: TestClient):
                     override=email_delivery_override,
                 ),
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
@@ -996,7 +992,7 @@ async def test_pless_login_smtp_service(driver_config_client: TestClient):
                     override=email_delivery_override,
                 ),
             ),
-            session.init(),
+            session.init(get_token_transfer_method=lambda _, __, ___: "cookie"),
         ],
     )
     start_st()
